---
name: Bug report
about: Create a report to help us improve Spotiflow
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Images/screenshots**
If applicable, add images or screenshots to help reproduce/explain your problem.

**Environment (please complete the following information):**
 - Spotiflow version: [e.g. 0.2.0]
 - Conda/mamba version (if applicable): [e.g. 4.13.0]
 - OS: [e.g. MacOS]
 - OS version: [e.g. 14.3]
 - GPU memory (if applicable): [e.g. 8GB]


**Additional context**
Add any other context about the problem here.
